Changelog
=========

Here you can see the full list of changes between each ``aiothrift`` release.

Version 0.1
-----------

First public release.

Version 0.1.1
-----------

allow kyeword arguments to `create_server`
